#
# spec file for package xpra
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2012-2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%ifarch x86_64 ppc64 s390x aarch64 riscv64
%global with_pandoc 1
%endif
%bcond_with pandoc

%define xpra_ver 4.2.3
%define html5_ver 4.5.1
%define uglifyjs_ver 3.14.2
%global __requires_exclude ^typelib\\(GtkosxApplication\\)|typelib\\(GdkGLExt\\)|typelib\\(GtkGLExt\\).*$
Name:           xpra
Version:        %{xpra_ver}
Release:        pm152.20.1
Summary:        Remote display server for applications and desktops
License:        BSD-3-Clause AND GPL-2.0-or-later AND LGPL-3.0-or-later AND MIT
URL:            https://www.xpra.org/
Source0:        https://xpra.org/src/%{name}-%{version}.tar.xz
Source1:        xpra-icon.png
Source2:        https://xpra.org/src/%{name}-html5-%{html5_ver}.tar.xz
Source3:        https://registry.npmjs.org/uglify-js/-/uglify-js-%{uglifyjs_ver}.tgz
# PATCH-FIX-OPENSUSE xpra-paths.patch -- use suse-specific paths
Patch0:         %{name}-paths.patch
BuildRequires:  ImageMagick
BuildRequires:  brotli
BuildRequires:  cups
BuildRequires:  cups-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
# Needed by uglify-js
BuildRequires:  nodejs-common
BuildRequires:  pam-devel
%if %{with pandoc}
BuildRequires:  pandoc
%endif
BuildRequires:  pkgconfig
BuildRequires:  python3-Cython >= 0.20.0
BuildRequires:  python3-devel
BuildRequires:  python3-gobject-devel
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libavcodec) >= 58
BuildRequires:  pkgconfig(libavformat) >= 58
BuildRequires:  pkgconfig(libswscale) >= 5
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libwebp) >= 0.4
BuildRequires:  pkgconfig(py3cairo)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(vpx) >= 1.4.0
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xtst)
Requires:       dbus-1-x11
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good
%if 0%{?sle_version} && 0%{?sle_version} < 150300
Requires:       pulseaudio
%else
Requires:       pulseaudio-daemon
%endif
Requires:       pulseaudio-utils
Requires:       python3-Pillow
Requires:       python3-cairo
Requires:       python3-dbus-python
Requires:       python3-gobject-Gdk
Requires:       python3-gst
Requires:       python3-lz4
Requires:       python3-opencv
Requires:       python3-pycups
Requires:       python3-rencode
Requires:       shared-mime-info
Requires:       xf86-video-dummy
Requires:       xorg-x11-xauth
Requires(post): %fillup_prereq
Recommends:     pinentry
Recommends:     python3-dnspython
Recommends:     python3-opencv
Recommends:     python3-opengl
Recommends:     python3-opengl-accelerate
Recommends:     python3-paramiko
Recommends:     python3-pyinotify
%{?systemd_ordering}

%description
Xpra is "screen for X": it allows you to run X programs, usually on a remote
host, direct their display to your local machine, and then to disconnect from
these programs and reconnect from the same or another machine, without losing
any state. It gives you remote access to individual applications.

Xpra is "rootless" or "seamless": programs you run under it show up on your
desktop as regular programs, managed by your regular window manager.
Sessions can be accessed over SSH, or password protected over plain TCP sockets.
Xpra is usable over reasonably slow links and does its best to adapt to changing
network bandwidth constraints.

%package        html5
Version:        %{html5_ver}
Summary:        HTML5 server and client support for xpra
Requires:       %{name} = %{xpra_ver}
# websockify is required to allow xpra to listen for an html5 client
Requires:       python3-websockify
Provides:       bundled(js-aurora)
Provides:       bundled(js-bencode)
Provides:       bundled(js-broadway)
Provides:       bundled(js-forge)
Provides:       bundled(js-jquery) = 3.1.1
Provides:       bundled(js-jquery-ui) = 1.12.1
Provides:       bundled(js-lz4)
Provides:       bundled(js-zlib)
BuildArch:      noarch

%description    html5
This package adds websockify support to allow xpra to listen for http
connections, and also the xpra html5 client.

%prep
%setup -q -a 2 -a 3
%autopatch -p1
# fix shebangs
find -name '*.py' \
     -exec sed -i '1{\@^#!/usr/bin/env python@d}' {} +
install -m0644 %{SOURCE1} -T fs/share/icons/xpra.png
# set fillup dir
sed -e 's|__FILLUPDIR__|%{_fillupdir}|' \
    -e 's|__UNITDIR__|%{_unitdir}|' \
    -e 's|share/doc/xpra|share/doc/packages/xpra|' \
    -i setup.py

sed -i '/install_html5/s/verbose=False/verbose=True/' %{name}-html5-%{html5_ver}/setup.py

%build
export CFLAGS="%{optflags}"
%if 0%{?suse_version} <= 1500
export CFLAGS="$CFLAGS -Wno-error=deprecated-declarations"
%endif
python3 setup.py clean

python3 setup.py build \
    --verbose \
    --with-enc_ffmpeg \
    --with-vpx \
    --with-dec_avcodec2 \
    --with-csc_swscale \
    --with-webp \
    --with-Xdummy \
    --with-Xdummy_wrapper \
    --with-opengl \
    --with-service \
    --without-cuda_kernels \
    --without-nvenc \
%if !%{with pandoc}
    --without-docs \
%endif
    --without-nvfbc

%install
python3 setup.py install \
    --skip-build \
    --root %{buildroot} \
    --prefix %{_prefix} \
    --with-service \
    --with-Xdummy \
    --with-Xdummy_wrapper \
%if !%{with pandoc}
    --without-docs \
%endif
    --verbose

pushd %{name}-html5-%{html5_ver}
PATH=$PATH:../package/bin python3 setup.py install %{buildroot}%{_datadir}/%{name}/www
popd

rm -rf %{buildroot}%{_datadir}/xpra/cuda

%suse_update_desktop_file -r xpra Network RemoteAccess
%suse_update_desktop_file -r xpra-gui Network RemoteAccess
%suse_update_desktop_file -r xpra-launcher Network RemoteAccess

mkdir -pv %{buildroot}%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%fdupes -s %{buildroot}

%pre
getent group xpra >/dev/null || groupadd -r xpra
mkdir -p %{_rundir}/%{name} || exit 1
%service_add_pre %{name}.service
%service_add_pre %{name}.socket

%post
%service_add_post %{name}.service
%service_add_post %{name}.socket
%fillup_only %{name}
%tmpfiles_create %{_tmpfilesdir}/xpra.conf

%preun
%service_del_preun %{name}.service
%service_del_preun %{name}.socket

%postun
%service_del_postun %{name}.service
%service_del_postun %{name}.socket

%files
%doc docs/README.md docs/CHANGELOG.md
%if %{with pandoc}
%doc %{_defaultdocdir}/xpra
%endif
%license COPYING
%dir %{_datadir}/xpra
%dir %{_prefix}/lib/xpra
%dir %{_sysconfdir}/pam.d
%dir %{_sysconfdir}/xpra
%dir %{_sysconfdir}/xpra/conf.d
%dir %{_sysconfdir}/xpra/content-categories
%dir %{_sysconfdir}/xpra/content-type
%dir %{_sysconfdir}/xpra/http-headers
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/xpra.conf
%config(noreplace) %{_sysconfdir}/pam.d/xpra
%config(noreplace) %{_sysconfdir}/xpra/*.conf
%config(noreplace) %{_sysconfdir}/xpra/conf.d/*.conf
%config(noreplace) %{_sysconfdir}/xpra/content-categories/*.conf
%config(noreplace) %{_sysconfdir}/xpra/content-type/*.conf
%config(noreplace) %{_sysconfdir}/xpra/http-headers/*.txt
%config(noreplace) %{_sysconfdir}/X11/xorg.conf.d/90-xpra-virtual.conf
%{_fillupdir}/sysconfig.%{name}
%{_bindir}/run_scaled
%{_bindir}/xpra
%{_bindir}/xpra_Xdummy
%{_bindir}/xpra_launcher
%{_bindir}/xpra_signal_listener
%{_bindir}/xpra_udev_product_version
%{_udevrulesdir}/71-xpra-virtual-pointer.rules
%{_prefix}/lib/xpra/auth_dialog
%{_prefix}/lib/xpra/gnome-open
%{_prefix}/lib/xpra/gvfs-open
%{_prefix}/lib/xpra/xdg-open
%{_sbindir}/rc%{name}
%{python3_sitearch}/xpra
%{python3_sitearch}/%{name}-%{xpra_ver}-py%{python3_version}.egg-info
%{_datadir}/applications/xpra-gui.desktop
%{_datadir}/applications/xpra-launcher.desktop
%{_datadir}/applications/xpra-shadow.desktop
%{_datadir}/applications/xpra.desktop
%{_datadir}/metainfo/xpra.appdata.xml
%{_datadir}/pixmaps/xpra-mdns.png
%{_datadir}/pixmaps/xpra-shadow.png
%{_datadir}/pixmaps/xpra.png
%{_datadir}/mime/packages/application-x-xpraconfig.xml
%{_datadir}/xpra/bell.wav
%{_datadir}/xpra/css
%{_datadir}/xpra/icons
%{_prefix}/lib/cups/backend/xpraforwarder
%{_mandir}/man1/run_scaled.1%{?ext_man}
%{_mandir}/man1/xpra.1%{?ext_man}
%{_mandir}/man1/xpra_launcher.1%{?ext_man}
%{_sysusersdir}/xpra.conf
%{_tmpfilesdir}/xpra.conf
%{_unitdir}/xpra.service
%{_unitdir}/xpra.socket
%ghost %dir %{_rundir}/xpra

%files html5
%{_datadir}/xpra/www

%changelog
* Wed Dec  1 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unused pkgconfig(pygtk-2.0) BuildRequires: Not used since
  version 4.0, when python 2 support was dropped.
- Add pre, post, preun and postun handling of xpra.socket.
* Mon Oct  4 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.2.3
  * network layer:
    + ensure the http headers cache is never modified
    unintentionally
    + invalid packet encoder names should not cause fatal errors
    + preserve audio packets chunking (avoids an HTML5 client
    bug)
    + prefer https links
    + prefer sha256 to sha1 for file transfer checksums
    + mmap setup error handling
    + `sndbuf_bytes` value was incorrect (currently unused)
    + socket timeout too long - broke VNC connections
    + AES DoS with unreasonably large number of password
    stretching iterations
    + tone down http content security policy for the HTML5 client
    + parsing of remote ssh command output
    + reply with a 404 if we have no http data to send
    + stricter validation of challenge digest attribute
    + stricter validation of packet indexes
    + specifying invalid compressors should not be fatal
    + handle more VNC clients correctly
    + server errors when VNC clients are connected
    + proxy sessions not found due to socket-dirs
    + mmap group lookup
  * encodings:
    + don't enable video encoders not present in 'encodings'
    option
    + ffmpeg H264 errors with unreleased version
    + ffmpeg codecs silencing too many warnings
    + vpx encoder lossless mode detection
    + potential race conditions in the proxy server's encoder
    loop
    + visual corruption with scaled jpeg updates
    + incorrect error messages with the jpeg YUV decoder
    + error in 'void' paint events (currently unused)
    + CUDA 11.4 and Ampere cards
    + RPM build errors when CUDA is disabled
    + restrict the number of NVENC errors tagged as transient
    + more robust OpenGL picture decoding sanity checks
  * packaging and platforms:
    + find the fakeXinerama library more reliably on all
    platforms
    + platform detection for CentOS / RedHat
    + missing default configuration files on MS Windows
    + missing webp with latest Pillow builds on MacOS
    + build fix for non-amd64 Debian (missing nvfbc)
  * clipboard selections getting stuck with MS Windows and MacOS
    clients
  * clipboard errors with some packet encoders sending strings
  * authentication modules not honouring `socket-dirs` option
  * make it easier to dismiss the splash screen
  * ssh password and key dialogs timing out without being shown
  * menu loading race condition causing empty start menu
  * window size hints may not have been honoured (rare case)
  * honour the force-replace-wm flag when upgrading
  * correctly handle command timeouts when probing servers
  * test scripts and command line tools fixups: unit tests, U2F
    tool, audio test, etc
  * system tray save-to-file debugging failures
  * minor cosmetic fixes to logging messages, unreachable code,
    icon loading errors
  * make it easier to run in a prefixed installation
- Update xpra-html5 to version 4.5.1 and uglify-js to 3.14.2
* Tue Aug 10 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.2.2
  * don't build ffmpeg codecs on i386 (crashy)
  * prevent crashes caused by svg conversion done in a thread
  * always stop the 'new-stream' notification process
  * prevent subprocesses from becoming zombies
  * clean server on 'stop' or 'exit'
  * fix application geometry issues
  * show correct default values with "xpra --help"
  * stop responding to 'info' requests when shutting down
  network layer:
  * honour the packet-encoding and compressors options
  * rencode packet encoder is not thread safe!
  * packet errors with bencoder and None values
  * don't assume the packet encoders handle bytes and / or
    strings
  client issues:
  * backwards compatibility with v3 servers for ssh start
  * incorrect client exit code
  subcommands:
  * 'start-gui' invalid options shown
  * 'sessions' and 'displays' subcommands do not need a display
  * fix hidden 'wmname' utility subcommand
  * many subcommands should send debug logging to stderr
  menu loading:
  * try harder to find valid menu entries to use
  * skip entries that cannot be executed
  * don't block the main thread when loading menus
  xpra top:
  * handle unicode window titles correctly
  * fix screen corruption due to threading
  * fix latency always showing as zero
  audio:
  * pipeline errors with aac encoder
  * X11 warning when starting microphone forwarding from the
    command line
  minor / cosmetic fixes:
  * cropped icons shown in html5 client connect page
  * logging, error handling
  * remove unused pulseaudio directories
  * '1080p' resize-display string matching
* Sun Jul 11 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.2.1
  build and packaging fixes:
  * missing dependencies
  * remove unused outdated code
  * remove runtime dependency on distutils for 'which'
  * cryptic error when a pkg_config file is missing
  proxy server:
  * deadlocks when queues fill up too quickly
  * honour mode and display
  * disconnections under heavy load
  Network:
  * fix RFB server protocol, sockets not timing out with VNC
    clients
  * invalid error when bind option points to a directory
  * detect wifi network connections more reliably
  * fix 'xpra' packet type auto detection
  * default to ssl-mode if the 'wss' socket option is not
    specified
  * 'keydata' connection attribute should override other options
  * correct exit code for encryption errors
  Encodings:
  * disable vaapi in ffmpeg codec by default (crashy / buggy)
  * NVENC errors when retrying after a transient failure
  * scroll detection bugs
  * webp encoder invalid memory access (corruption)
  Misc:
  * notification forwarding errors with SVG icons
  * disable SVG icon resizing (potential crashes on some
    platforms)
  * missing log prefix for 'xpra recover' subcommand
  * faster server startup failures: don't wait for things that
    were not started (ie: audio)
  * fix commands started twice when upgrading (ie: ibus-daemon)
  * local start with explicit attach was broken on Posix
  * 'attach' option should not be forwarded to the server (which
    then fails)
  * invalid window resize counter (used for resize loop
    prevention)
  * missing icon errors when html5 client disconnects from
    system-wide proxy server
  * file transfer errors when a 'top' client is connected
  * don't claim that non-interactive clients use the screen
  * retry once after X11 query tree errors during startup
  * provide XDG_RUNTIME_DIR if it is not defined
  * add new 3x4K Xdummy modeline
  * minor cosmetic and debug logging fixes
* Sun Jun 20 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Add python3-pyinotify as recommended dependency to allow watch
  for video device changes
* Sat Jun 12 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.2
  * use pinentry for password prompts and ssh prompts
  * nvjpeg encoder - also requires this commit to the html5
    client
  * gui for starting remote sessions
  * new subcommands: recover, displays, list-sessions,
    clean-displays, clean-sockets - #3098, #3099
  * many fixes: window initial position, focus, non-opengl paint
    corruption, slow rendering on MacOS, build scripts, handle
    smooth scroll events with wayland clients, always lossy
    screen updates for terminals, clipboard timeout, peercred
    auth options
  * support multiple clients using mmap simultaneously with
    non-default file paths
  * only synchronize xsettings with seamless servers
  * automatic desktop scaling is now disabled
  * workaround for gnome applications starting slowly
- Update uglify-js to 3.13.9
- Refresh xpra-paths.patch
* Fri May  7 2021 Dirk Müller <dmueller@suse.com>
- fix build on architectures without pandoc
* Fri Apr 23 2021 Luigi Baldoni <aloisio@gmx.com>
- Fix build with ffmpeg 4.4 on Leap
* Wed Apr 21 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.1.3
  * fix window geometry constraints being applied wrong
  * fix xpra start failures when the display is already running
    (with use-display=auto)
  * fix vp9 libvpx encoder failures with older library versions
  * fix 'xpra top' errors when the version string is missing
  * fix server errors when non interactive clients are connected
    (ie: 'xpra top')
  * fix http server error on incomplete installations
  * fix http server builtin script handler
  * fix icon loading errors causing empty start menus
  * fix compilation against ffmpeg 4.4 and later on some
    distributions
  * exit more quickly with a failure if the VFB failed to start
  * correctly replace existing notifications with the gtk
    notifier backend
  * silence some rare errors and stacktraces
  * support CUDA 11.3
- Update uglify-js to 3.13.4
* Tue Apr  6 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.1.2
  * fix unnecessary screen update delays
  * fix screen refresh rate detection
  * increase the default screen update refresh rate
  * fix missing encodings with 'upgrade' and 'upgrade-desktop'
    subcommands
  * fix client failures due to missing socket directories
  * more correct API usage of 'notify2' backend
  * fix `run_scaled` script handling of multiple arguments
  * fix ioctl error with nested SSH connections
  * fix video region detection error
  * fix sessions GUI not updating on process exit
  * fix compatibility with newer versions of python-zeroconf
  * fix directory listing with the builtin http server (still
    disabled by default)
  * fix the server's GetAll dbus property handler
  * fix display-name validation check
  * the 'exec-wrapper' option no longer needs to use an absolute
    path
  * ignore bell audio devices
  * show the correct list of pressed keys, unkown modifiers
  * prevent the splash screen process from consuming too much CPU
  * better service configuration file location detection
  * packaging script fixes, library and documentation updates
- Update xpra-html5 to 4.1.2 and uglify-js to 3.13.3
- Refresh xpra-paths.patch
* Wed Mar 17 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.1.1 (fixes boo#1182526)
  * ensure splash screen failures are not fatal, fix threading
    bug
  * avoid vaapi crashing in ffmpeg encoder
  * `xpra top` fixes:
    + correctly show the version number
    + laggy input handling and screen updates
    + long subcommand timeout
  * fix connection errors with trailing slash in display name
  * workaround API breakage in newer versions of python-zeroconf
  * warn just once if expected GStreamer element properties are
    missing
  * map more applications to text mode ('code', 'jetbrains')
  version 4.1:
  * Overhauled container based build system
  * Splash screen
  * `run_scaled` utility script
  Client:
  * header bar option for window control menu
  * generate a qrcode to connect
  * show all keyboard shortcuts
  * progress bar for file transfers
  * GTK cairo backend support for more native bit depths
  * disable xpra's keyboard shortcuts from the system tray menu
  * automatically include the server log in bug reports
  OpenGL client backend:
  * render at fixed bit depths with the `pixel-depth` option
  * support more bit depths
  Clipboard:
  * MacOS support for images, more text formats, etc
  * MS Windows support for images
  * wayland clients
  Server:
  * faster server startup
  * `xpra list-windows` subcommand
  * new window control commands: move - resize
  * remote logging: from server to client
  * support window re-stacking
  `xpra top`:
  * show pids, shortcuts
  * more details in the list view
  * show speed and quality
  Display:
  * bumped maximum resolution beyond 8K
  * set the initial resolution more easily using the
    'resize-display' option
  Encoding:
  * server side picture downscaling
  * libva hardware accelerated encoding
  * NVENC 30-bit accelerated encoding
  * vpx 30-bit
  * x264 30-bit
  * faster 30-bit RGB subsampling
  * scroll encoding now handled more generically
  * black and white mode
  Network:
  * IGD / UPNP
  * SO_KEEPALIVE option
  * clients can be queried using local sockets
  * specify connection attributes using the connection string
  * nested SSH tunnels
  * websocket header modules
  * specify the socket type with socket activation
  * expose the packet flush flag
  * `xpra shell` subcommand for interacting with processes in
    real time
  * custom group sockets directory permissions and name
  Testing:
  * better test coverage
  * cleanup output
- Refresh xpra-paths.patch
- Add xpra-html5 (now distributed separately) and uglify-js
  (required by the former) tarballs
- Spec cleanup
* Thu Feb 25 2021 Antonio Larrosa <alarrosa@suse.com>
- Require the pulseaudio-daemon capability instead of the
  pulseaudio package, so alternative implementations can be used
  (boo#1182730).
* Wed Feb 10 2021 olaf@aepfle.de
- Fix regex for /bin/bash
* Fri Feb  5 2021 olaf@aepfle.de
- Fix requires for /bin/bash
* Thu Dec 31 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.0.6
  * fix screen refresh performance issues, especially on jittery
    links
  * fix proxy instance control socket errors and process leak
  * fix slow subcommands due to unnecessary calls to ldconfig
  * fix server asynchronous packets getting delayed
  * fix 'xpra _proxy' zombies getting left behind (ssh mode)
  * fix failures to enable packet compression
  * fix connection errors when a non interactive client is
    already connected
  * fix ssh connection errors with proxycommand or proxyhost
    port numbers
  * fix timeouts with paramiko ssh client
  * fix ssh string escaping with MS Windows clients
  * fix client rejecting printing requests
  * fix duplicate / untimely audio-stop control packets with
    HTML5 client
  * fix console errors with Internet Explorer
  * fix capslock regression on MacOS and MSWindows shadow servers
  * fix errors accessing window handles on MS Windows (size
    hints, opengl, etc)
  * fix spurious refresh packets with mmap
  * fix mmap not used with some non-video areas
  * fix keyboard sub-layout detection with MS Windows clients
  * fix clipboard cleanup errors on MS Windows
  * fix clipboard with Wayland clients
  * fix window repaint with Wayland clients
  * fix printing diagnostic script
  * fix Python 3.9 compatibility
  * fix sysconfig path in systemd service file
  * fix xdg-open override script error handling
  * fix file-transfer failures with small files
  * fix file-transfers with non-ascii filenames
  * fix FIPS compatibility (no md5)
  * better file transfer message format
  * honour XPRA_XDG_EXPORT_ICONS=0 env var in all cases
  * hide passwords from authentication debug logging
  * make it possible to specify the socket type with systemd
    socket activation
  * re-add "~/.xpra" as socket-dir
  * typo in man page
- Refresh xpra-paths.patch
* Wed Nov 18 2020 aloisio@gmx.com
- Update to verison 4.0.5
  * fix caps lock wrongly applied to numeric keys
  * fix HTML5 client keyboard layout detection with Internet
    Explorer
  * fix HTML5 audio forwarding with some versions of Safari
  * fix HTML5 (un)fullscreen
  * fix ssl server hostname verification errors
  * fix syntax errors when using connections using nested ssh
    tunnels
  * fix socket_util import errors with some subcommands
  * fix http / websocket and ssl socket upgrade failures
  * fix server errors when ws sockets cannot be upgrade to wss
  * fix ssh command option not being honourd with the client
    launcher
  * fix proxy control socket becoming unresponsive after errors
  * fix proxy shutdown
  * fix proxy instance zombies on server start failures
  * fix sqlite authentication module not handling configuration
    options
  * fix stdout errors causing server startup or shutdown problems
  * fix Wayland detection and workarounds
  * fix clipboard errors under Wayland
  * fix client signal listener not forwarding signal messages
  * fix client failing to connect due to keymap changes (ie:
    Wayland)
  * fix client not showing authentication prompt only once per
    connection
  * fix opengl debug option for saving buffers as jpeg
  * fix spurious "missing resolution" errors (often with HTML5
    client resizing)
  * fix duplicated data in bug reports
  * fix download checksum verification (was not verified with
    python3 builds)
  * fix spurious file transfer errors with python3 builds
  * fix NVENC session leak due to flushing errors, support
    building with SDK10
  * remove "numpy" dependency for builds without NVENC / NVFBC
  * add new NVENC presets from SDK v10, workaround deprecation
    warnings
  * HTML5 connect page can now specify the display to connect to
  * avoid starting new threads for file transfers that don't
    need one
  * raise default maximum packet size to prevent connection
    errors with large xdg menu data
  * don't let bad http requests mess up the server log
  * prevent peek data or exception message from corrupting the
    log / stdout
  * remove dependency on "requests" package introduced in 4.0.4
  * make it possible to override the Xorg binary path detection
* Sun Sep 27 2020 aloisio@gmx.com
- Update to version 4.0.4
  * fix memory leak with 'scroll' encoding
  * fix NVENC encoder (profile errors)
  * fix unmanaged X11 message call which could cause GTK to
    crash when it fails
  * fix missing auto-refresh leaving a blurry image
  * fix incomplete repaints when window contents have padding
  * fix missing pixels on the edge of video areas in 'auto'
    encoding mode
  * fix connection errors with notifications disabled on the
    server
  * fix 'sync-xvfb' option: setup error, non-standard bit depth
    support
  * fix shadow server dbus SetRefreshDelay causing all further
    "xpra info" requests to fail
  * fix incomplete data in initial packets from shadow servers
  * fix error in dbus debug logging
  * fix client invalid list of encodings
  * fix workspace spurious warnings on 64-bit X11 systems
  * fix named-pipe server clash
  * fix syntax error in HTML5 client maximize toggle
  * fix keysym mapping with Xkb and some specific configurations
  * fix right click on systray using the gtk StatusIcon
    implementation
  * fix small file transfers not showing as completed
  * fix file-transfer UI for download vs download-and-open not
    being honoured
  * fix file-transfer identifiers getting lost
  * fix websocket compatibility with some client / middleware
  * fix missing windows due to an error in the named window icon
    handling
  * fix hard to trigger mmap memory leak
  * add support for sm86 architecture with CUDA 11.1
  * allow 'pager' source indication value to activate window
    server-side
  * workaround corruption on some windows when maximized
  * workaround more pyxdg bugs
  * make OpenGL probe timeout configurable
* Mon Sep  7 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Wed Aug 19 2020 Luigi Baldoni <aloisio@gmx.com>
- Use proper location of bash in script shebang
- Add runtime requirement
* Wed Aug 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%{_udevrulesdir} consistently throughout the .spec.
* Sat Aug  8 2020 aloisio@gmx.com
- Update to version 4.0.3
  * fix server crash caused by use after free in scrolling code
  * fix encryption option overzealously enforced on all socket
    types
  * fix network layer compression errors that can cause
    connections to drop
  * fix printing errors with some shell character encodings
  * fix NVENC h264 stream compatibility with HTML5 client
  * fix windows not getting focused when clicking on title bar
    (HTML5)
  * fix suspend / resume errors with tray windows
  * fix garbled terminal when ssh messages and 'top' client
    conflict
  * fix OpenGL force-enable option not honoured
  * fix tray geometry errors
  * fix socket setup error handler
  * fix minimum video scaling not being honoured via heuristics
  * fix error in main thread verifier (fortunately, never fired)
  * fix archlinux build root stripping
  * fix detection of named-pipe creation errors
  * fix clipboard data sometimes going missing when ownership
    changes
  * fix memory contents of the swscale pixel format object
  * fix csc_swscale converter getting recycled every time
  * fix division by zero errors during window cleanup
  * fix rfb connections missing all screen updates
  * fix toolbox examples when running under wayland
  * fix notification widget wrongly stealing input focus
  * fix support for building with CUDA 11.0
  * fix unshrinkable session-info window
  * fix window resizing errors when non-GUI clients are also
    connected
  * avoid ever using b-frames for text content
  * avoid opengl warning with wayland
  * add extra environment variables to try to disable any server
    side scaling
  * also update mdns records when the session name changes
  * workaround for older versions of python-cryptography
  * use 'text' mode for 'geany' (fixes lossy screen updates)
  * ensure all toolbox windows set a correct and readable window
    title
  * make it possible to specify the path used for saving video
    streams / frames
* Fri Jul 17 2020 Markus Ebner <info@ebner-markus.de>
- add python3-opengl, and python3-opengl-accelerate as recommended
  dependencies, to support OpenGL in the client
* Fri Jun  5 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.0.2
  * fix encryption not honoured with TCP sockets upgraded to
    WebSocket
  * fix xpra top client refresh rate via timer
  * fix opengl client info format shown in 'xpra top'
  * fix format of attributes given to glXChooseVisual
  * fix crashes in OpenGL context setup on X11
  * fix race condition in window statistics
  * fix server errors when non-interactive clients are connected
  * fix tray toolbox app
  * fix X11 server key symbol lookup via Xkb
  * html5 fixes:
    + fix missing desktop background
    + client errors painting rgb32 data with a padded rowstride
    + clipboard wrongly clearing data on failures
    + compatibility issues with Internet Explorer
    + missing transparency for windows in focus
    + no windows focused after close
    + connection errors caused by spurious packets
    + error in invalid packet handler
    + AES encrypted connections
    + connection errors with AES and lz4 (disable lz4 for now)
    + packet error with very small paint packets
    + 'insecure passwords' option shown in the wrong cases
    + handle window iconification messages
    + update version in about page
  * fix connection errors with 'None' values in bencoder (ie:
    html5)
  * fix connection errors with websocket connections and AES
    encryption
  * fix duplicate clipboard token sent with MS Windows servers
  * fix window initialization errors causing server startup
    failures
  * remove invalid extra strings from mdns service name
  * workaround bugs in pyxdg / menu configuration
  * add 'terminator' to the 'text' application hint
  * more explicit error message when trying to use python2
* Sun May 17 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.0.1
  * fix missing content-type for some windows
  * fix GTK server crash on exit
  * fix compatibility with newer versions of uglifyjs
  * fix ssh session start and attach on Posix systems
  * fix 'xpra send-file' to use absolute file paths
  * fix MacOS shadow servers failing to accept connections
* Sun May 10 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.0
  * Drop support for:
    + Python 2, GTK2
    + legacy versions (pre 1.0)
    + weak authentication
  * Network, per socket options:
    + authentication and encryption
    + ssl
    + ssh
    + bind options for client
  * make it easier to send files from the server
  * xpra toolbox subcommand
  * xpra help subcommand
  * xpra top new features
  * faster startup
  * signal handling fixes
  * smoother window resizing
  * refactoring and testing
    + unit tests coverage and fixes
    + completely skip loading unused features at runtime
    + get rid of capabilities data after parsing it
    + better module dependency separation
    + don't convert to a string before we need it
  * more useful window and tray title
  * make it easier to source environment
  * disable desktop animations in desktop mode
  * automatic start-or-upgrade, automatic X11 display rescue
  * support MS Windows OpenSSH server to start shadow
  * more selective use of OpenGL acceleration in client
  * expose server OpenGL capabilities
  * cleaner HTML5 syntax
- Refresh xpra-paths.patch
* Tue Apr 14 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.9
  * fix HTML5 client XSS
  * fix focus issues
  * fix server hangs and unpainted windows due to invalid
    dimensions
  * fix window icons and cursors visual corruption or crashes
  * fix unbearably slow screen updates when vrefresh value is
    invalid
  * fix client OpenGL crashes with remote starts (run probe
    first)
  * fix keypad regression (AltGr changes, again)
  * fix MS Windows shadow servers
  * fix race condition collecting latency data for session info
  * fix missing pycuda dependency for nvenc on MS Windows
  * fix missing signatures on MS Windows EXE and MSI builds
  * fix scoring of NVENC codec (should be used ahead of sofware
    encoders)
  * fix start menu updates getting lost
  * fix OpenGL diagnostic messages getting cut off
  * fix change of encoding from the system tray
  * fix quality and speed changes from the system tray
  * fix clipboard and popup menu problems with Eclipse
  * fix name of shadow server process on MS Windows, used in log
    file names
  * fix audio query subprocess with MS shadow servers
  * fix unlikely race condition in speaker forwarding shutdown
    sequence
  * fix desktop-fullscreen=yes automatic scaling
  * fix missing bug report data due to uninitialized X11 bindings
  * fix bug report error if we cannot grab a screenshot (ie:
    Wayland)
  * fix error saving binary data with python3 builds of the bug
    report tool
  * fix errors querying the display under Wayland
  * hide scary stacktraces when shutting down ssh proxy commands
  * if we have an ssh password we can use, try that first
  * blacklist VirtualBox's SVGA3D OpenGL driver (fixes black
    windows)
  * don't use webp with image dimensions beyond its limits
  * use regular X11 system tray with i3
  * hide confusing named-pipe prefix in empty output on MS
    Windows
  * HTML5 fixes: invalid IMG tag, reserved keyword, language
    detection, draw debugging, etc
  * don't try to read /proc if not on Posix
  * use a more specific python3 interpreter version
  * update application content-type mappings
  * remove out of date information from man page
* Tue Mar 31 2020 aloisio@gmx.com
- Update to version 3.0.8
  * fix handling of dpi command line switch (correctly this
    time?)
  * fix bug report window not getting focus on MacOS
  * fix spurious ssh key warnings with newer versions of paramiko
  * fix AltGr mode with non-X11 clients, layout-group changes
  * fix rare unexpected client exit on MS Windows
  * fix MS Windows clipboard:
    + update failures
    + convert CRLF line endings
  * Clipboard:
    + fix selection not shown as active in menus (MS Windows and
    MacOS)
    + fix spurious warnings when sharing a session
    + fix clipboard reset with python2 builds
    + selection translation for outbound data
    + support client applications that don't use TARGETS (ie:
    Motif)
    + reject invalid targets
  * fix 'xpra upgrade' wrongly updating non-xpra displays
  * fix logging error in client geometry debugging output
  * fix spurious de-iconifications
  * fix handling of server control commands with python3 clients
  * fix UDP backport bug sending control packets
  * fix vfb getting killed on upgrade failure
  * fix proxy server cleanup: force forwarders to terminate
  * fix session info errors during client exit
  * fix printer cleanup errors with invalid UTF8 printer names
  * fix transient-for popup window workaround
  * fix unicode errors saving xpra runner shell script with
    python3
  * better detection of Wayland environments
  * use python3 (if installed) by default on Ubuntu Xenial
  * don't use Xdummy on arm, too slow
  * don't show 'Download' button that we can't honour
  * show all pressed keys according to X11 server in 'xpra info'
  * try harder not to use video for tiny areas
* Sat Mar 14 2020 aloisio@gmx.com
- Update to version 3.0.7
  * fix avcodec2 race condition crash
  * fix errors when re-initializing windows (ie: toggling OpenGL
    on or off)
  * fix deiconification error when there are system trays
    forwarded
  * fix missing alpha channel when some windows are first shown
  * fix systemd-run errors: verify it does work before trying to
    use it
  * fix server crashes on SIGINT: shutdown cleanly
  * fix proxy server client connection setup error hanlder
  * fix file authentication handler using a default password
    filename
  * fix directshow errors on local mingw installations
  * fix opengl properties missing from server hello packet
  * fix HTML5 sound-control errors when speaker forwarding is
    disabled
  * fix HTML5 "Terminate" options wrongly enabled in "Connect"
    mode
  * fix clipboard sharing with the MacOS shadow server
  * fix MS Windows clipboard access denied errors
  * fix X11 clipboard error handling: continue processing
  * fix unit tests failures (clipboard, etc)
  * fix bug report clipboard copy and screnshots
  * fix clipboard timeouts when a client disconnects
  * fix mdns cleanup done twice on server exit, causing errors
  * fix malformed XSettings due to invalid color data format
  * fix HMAC hashes exposed, keep only valid options
  * fix 'showconfig' output for boolean values set to 'auto'
  * fix parsing of client display information in legacy format
  * fix validation of size-hints
  * fix cursor saving debug code with GTK3
  * fix keyboard layout group not getting reset on client exit
  * fix some empty keyboard layout group strings parsed as
    non-empty
  * fix keyboard-sync mode not being honoured by servers
  * fix keyboard raw mode
  * fix missing 'perispomeni' key mapping with Python 2 servers
  * add missing debug logging to keyboard mapping
  * more reliable lookup of keycodes when translating (non-X11
    clients)
  * skip bundling some external test modules with binary
    installers
  * avoid spurious background worker warnings on exit
  * make unavoidable comtypes error less scary
  * add 'libreoffice' to the text mode whitelist
  * packaging workarounds for setuptools breakage
* Mon Feb 10 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.6
  * fix UDP with Python3
  * fix key mapping issues with non-X11 clients and non-US
    layouts
  * fix notification logging errors during shutdown
  * fix window stacking order with html5 client and override
    redirect windows
  * fix png/P and png/L decoding
  * fix very slow startup on Debian due to missing
    libfakeXinerama
  * fix display scaling notification warning
  * fix errors generating the tray title string
  * fix missing webp modules in 'clean' build target
  * fix some special characters with HTML5 client
  * fix initiate-moveresize with multiple clients
  * fix control commands argument error handling
  * fix unit tests
  * fix window repaint issues: system tray, Python 2 non-opengl
    window spinners
  * fix server errors during client connection cleanup
  * fix spacebar and other characters with tablet input devices
    (ie: mobile browsers)
  * fix unhelpful backtraces when client application windows are
    lost
  * fix for crashes on X11 displays lacking RandR support
  * fix handling of non 24/32-bit png window icons
  * man page connection string fixes
  * disable cpuinfo module - known to cause problems on various
    platforms
  * ignore error and continue when loading version information
    from invalid builds
  * remove executable file permissions on files uploaded to the
    server
  * blacklist 'Intel(R) UHD Graphics 620'
  * use correct location for appdata.xml
  * use Debian location for systemd service config file
  * ensure emacs, gvim and xxdiff always use 'text' mode
  * re-enable pulseaudio memfd (was wrongly disabled in v3.0.0)
  * remove remnants of GTK2 dependencies from non-GTK2 components
  * add missing entry to path information tool
- Refreshed xpra-paths.patch
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Tue Jan 28 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.5
  * fix fake Xinerama errors with unicode monitor names
  * fix av-sync backport for python2 servers
  * fix errors when the dbus submodule is not installed
  * fix RFB server key handling
  * fix exit code for unsupported sockets
  * fix tray title with openssh and plink SSH backends
  * fix 'xpra upgrade'
  * fix focus problems with OR windows
  * fix wrong client info shown in 'xpra top'
  * fix 'xpra top' error that scrambled the output, flickering
  * fix X11 keyboard query against secondary screens
  * skip trying to load X11 components on non-X11 platforms
  * allow F11 through to the browser to make it easier to go
    fullscreen
  * prevent sshfp dns errors from causing ssh connection failures
  * obscure passwords from log files
  * remove duplicated attribute from xpra info
  * remove unused loggers
  * expose av-sync and webcam client capabilities
  * better wayland mode detection
  * add more missing files to MANIFEST
  * add v4l2 codec files to clean target
  * add logging to gtk display cleanup
- Refreshed xpra-paths.patch to update systemctl location
* Mon Dec 23 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.4
  * fix av-sync
  * fix X11 property synchronization error due to race condition
  * fix XI2 bindings not loading
  * fix ssh upgrades wrongly claimed as supported when paramiko
    is not installed
  * fix 'wireless' network device detection on Linux
  * fix 'Sound Buffer' graph
  * fix errors caused by window title error handler
  * fix missing 'Packet Encoders' and 'Packet Compressors' with
    python3 clients
  * distinguish certificate verification errors from other ssl
    errors
- Enable ffmpeg encoder for Leap
* Wed Dec 11 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.3
  * fix clipboard synchronization with HTML5 client
  * fix window repaints with GTK3
  * fix GDK scaling causing window painting issues (force off)
  * fix slow repaint with OpenGL and combined updates (ie:
    scrolling)
  * fix missing video screen updates with 32-bit browsers:
    disable video
  * fix for X11 applications requesting invalid clipboard targets
  * fix "xpra top" errors when the terminal window is too small
  * fix blank xpra dialog windows when closed then shown again
    (ie: server commands)
  * fix compilation on non-i386 32-bit platforms
  * fix platform query errors causing command failures
  * fix Python2 builds: ignore GTK2 deprecation warnings
  * fix X11 property synchronization with Python2 builds
  * fix XSetClassHint call with Python 3
  * fix window move + resize shortcut
  * fix ssh proxy options not preserved when loading session
    files
  * fix error and missing refresh after changing quality or
    speed settings
  * fix NVENC error when pynvml is not installed
  * fix NVENC temporary failure retry code path
  * fix DPI value from the command line with desktop-scaling
  * fix typo in man page
  * fix errors with some odd Python3 builds
    (subprocess.getoutput)
  * fix cursor packets missing encoding attribute
  * fix notification error handling the speaker forwarding error
    message
  * fix incorrect and unhelpful message on connection error
  * make it possible to disable colourspace synchronization
  * show mdns status in xpra info
  * support CUDA 10.2
* Wed Nov 20 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.2
  * fix clipboard synchronization issue with MS Windows clients
    properly
  * fix Pillow 6.x compatibility with MS Windows packaging
  * fix null bytes in X11 error text properly
  * fix Python 3 servers wrongly re-sending the 'screen'
    attribute
  * fix remote logging failures with some message formats
  * fix lost screen updates
  * fix GTK scaling causing window geometry issues
  * fix HTML5 clipboard data sent from polling events
  * fix CUDA device logging with multiple devices
  * fix 32-bit build errors on xxhash
  * fix RPM jpeg and libyuv dependencies
  * fix OpenGL window not refreshing with Python 3
  * fix OpenGL context held for too long
  * fix SSH connection errors when 'port' is specified in the
    ssh config
  * fix faac and faad2 security issues in MS Windows and MacOS
    builds
  * fix window size hints misapplied with GTK3 on MS Windows and
    Wayland
  * disable OpenGL acceleration on old Intel chipsets
  * disable OpenGL acceleration with GTK3 builds on MS Windows
    (for now, pending bug)
  * show python interpreter version on about dialog
  * re-instante ancient popup window workaround (was disabled by
    mistake)
  * don't use av-synchronization for text and picture content
    types
  * workaround Fedora packaging causing gratuitious conflicts
* Sun Nov  3 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.1
  * fix clipboard synchronization failures with MS Windows
    clients
  * fix window cleanup errors preventing a clean exit
  * fix launcher error if sharing flag is unset
  * fix window states wrongly getting reset
  * fix SSH password dialog lockups on MS Windows
  * fix authentication module errors (multifile, python3)
  * fix radio buttons on start server dialog (python3)
  * fix error in encoding selection fallback (python3)
  * fix logging error in cups printing backend (python3)
  * fix null bytes in X11 error text (notifications errors)
  * fix keyboard debug logging error
  * fix error querying X11 properties under pure wayland client
  * fix unresponsive appindicator system tray
  * fix GDK window scaling setting wrongly propagated to the
    server
  * fix compilation on Ubuntu Eoan Ermine
  * fix file download failures on MS Windows due to invalid
    characters
  * fix handling of file download errors
  * fix Debian bin path warnings
  * fix error handling in 'xpra top'
  * fix pyobjc API compatibility in OpenGL transparency shim
  * fix out of date PKG OS version requirements
  * fix PKG compatibility with MacOS 10.15 Catalina
  * fix window border color parsing failures causing errors
  * fix OpenGL window paint errors with some drivers
  * make it easier to launch test tools
  * update Python to 3.7.5 on MacOS
  * bump revision to override broken Fedora packaging
  * show Python version in MacOS packages
  * re-enable tooltips on MS Windows
  * update to xxhash 0.7.2
  * consistent use of quotes in endpoint logging
- Spec cleanup
* Wed Oct  2 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0
  * Python 3 port complete, now the default: #1571, #2195
  * much nicer HTML5 client user interface: #2269
  * Window handling:
    + smoother window resizing: #478 (OpenGL)
    + honouring gravity: #2217
    + lock them in readonly mode: #2137
  * xpra top subcommand: #2348
  * faster startup:
    + #2347 faster client startup
    + #2341 faster server startup
  * OpenGL:
    + more reliable driver probing: #2204
    + cursor paint support: #1497
    + transparency on MacOS: #1794
  * Encoding:
    + lossless window scrolling: #1320
    + scrolling acceleration for non-OpenGL backends: #2295
    + harden image parsing: #2279
    + workaround slow video encoder initialization (ie: NVENC)
    using replacement frames: #2048
    + avoid loading codecs we don't need: #2344
    + skip some CUDA devices, speedup enumeration: #2415
  * Clipboard:
    + new native clipboard implementations for all platforms:
    [#812]
    + HTML5 asynchronous clipboard: #1844
    + HTML5 support for copying images: #2312 (with watermarking)
    + brotli compression for text data: #2289
  * Authentication:
    + modular client authentication handlers: #1796
    + mysql authentication module: #2287
    + generic SQL authentication module: #2288
  * Network:
    + client listen mode: #1022
    + retry to connect until it succeeds or times out: #2346
    + mdns TXT attributes updated at runtime: #2187
    + zeroconf fixes: #2317
    + drop pybonjour: #2297
    + paramiko honours IdentityFile: #2282, handles SIGINT
    better: #2378
    + proxy server fixes for ssl and ssh sockets: #2399, remove
    spurious options: #2193
    + proxy ping and timeouts: #2408
    + proxy dynamic authentication: #2261
  * Automated Testing:
    + test HTML5 client: #2231
    + many new mixin tests: #1773 (and bugs found)
  * start-new-commands is now enabled by default: #2278, and the
    UI allows free text: #2221
  * basic support for native GTK wayland client: #2243
  * forward custom X11 properties: #2311
  * xpra launcher visual feedback during connection: #1421,
    sharing option: #2115
  * "Window" menu on MacOS: #1808
- Refreshed xpra-paths.patch
- Switched build to python 3
* Sat Jul 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.5.3
  * fix HTML5 MSIE 11 detection
  * fix HTML5 path of audio script for IE
  * fix HTML5 CapsLock and NumLock state detection
  * fix HTML5 desktop server screen size not resizing to match
    window
  * fix shadow servers display resizing not being propagated
  * fix scroll encoding with multi monitor shadow servers
  * fix handling of uncompressed window icon pixel data
  * fix handling of unicode values for desktop names
  * fix remote ssh failures with python3-only installations
  * fix '_monitor' subcommand with python3 clients
  * fix client ping latency calculations
  * fix non-strict ssl host key not honoured with wss connections
  * fix handling of websocket and ssl traffic with unix-domain
    sockets
  * fix ssl and websocket connection upgrades with python3
    servers
  * fix handling of websocket ping packets
  * fix unnecessary delay in initial connection handling
  * fix incorrect disconnections with non-UI clients
  * fix spurious socket warnings
  * fix distro information shown for proxied connections
  * fix invalid mdns records for rfb connections (desktop and
    shadow servers)
  * fix GTK3 signal handling before the main loop is running
  * fix file descriptor leak when running child commands
  * fix clipboard-direction setting not propagated to the client
  * fix clipboard datatype shortcut not taken due to a typo
  * fix clipboard bugs with python3 builds, invalid atoms
  * fix overzealous cleanup code in X11 root property handler
  * fix Xresources debug logging and error handler
  * fix errors during cleanup: close display later
  * fix uinput device mode with python3 servers
  * fix errors if md5 is not available: use sha1
  * fix default build options for RedHat
  * fix typos in man page and docstrings
  * silence annoying atk warnings
  * avoid running invalid lpinfo commands
  * improve compatibility with 'xpra top'
  * make it possible to skip opengl probing during server startup
  * add missing modal-window entry in man page
  * reduce weak RPM dependencies on gnome components
* Fri Jun 14 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.5.2
  * fix mmap leak which can cause the client to stop painting
  * fix OpenGL crashes: don't try to use it when probing process
    has crashed
  * fix errors in avahi error handler
  * fix connection errors when loading ssh public keys
  * fix tests being run with the wrong python interpreter version
  * fix systemd-run using the wrong python interpreter version
  * fix start menu with python3 clients
  * fix x264 encoder failing to create a compatible stream for
    the html5 client
  * fix unnecessary xdg menu data in some subcommands
  * fix large xdg menu data causing initial packet size errors
  * fix packet size warning message format
  * fix start menu with python3 clients
  * fix html5 client connection error when xdg-menu data is
    missing
  * fix html5 client compatibility with buggy x264 encoders (as
    above)
  * fix html5 client clipboard packet format
  * fix session info graphs start values
  * fix colour channels swapped with some window icons and
    desktop servers
  * fix slower compression code path wrongly used when av-sync
    is disabled
  * fix icon type attribute (remove dot)
  * fix signal forwarding with python3 servers
  * fix system tray forwarding with python3 servers
  * fix socket attributes name lookup for xpra info
  * fix handling proxy server info requests
  * fix proxy server info errors trying to enumerate sessions
  * fix automatic MTU adjustements with UDP transport
  * fix NVENC compatiblity with library soname found in newer
    installers
  * fix invalid python2 DEB dependency in main meta package
  * fix default config value for opengl attribute
  * fix HTML5 client authentication issue when going through a
    proxy server
  * fix socket errors on startup with bind-ssl
  * fix server dbus service attribute accessor methods
  * fix network jitter injector
  * fix avahi mdns publisher test tool
  * fix zeroconf error when service info is not available
  * fix remote ssh failures with python3-only installations
  * fix automatic interpreter version switching when re-executing
  * fix start-via-proxy exit code handler
  * fix socket-permissions option not being honoured
  * fix error in the codec loader if the first codec attempted
    fails
  * fix error in the codec instantiation leak detection code
  * fix exit hooks not being called with 'exit-with-client'
  * fix RandR build errors with older versions of Cython (ie:
    Xenial)
  * fix GTK3 build of the keyboard test tool on MS Windows
  * fix errors parsing xresources
  * fix handling of xsettings with python3 servers
  * fix font hinting detection with python3
  * fix errors during cleanup if server initialization or
    startup had failed
  * fix pure python3 builds cairo headers used
  * updated package dependencies: recommend python-dns for sshfp
    support
* Fri Apr 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.5.1
  * fix sending of icons as premultipled ARGB
  * fix compatibility with old versions of python-pillow
  * fix scroll encoding code flow (should be impossible to hit)
  * fix handling of info requests with Python3 servers
  * fix missing option for lock argument in man page
  * fix ssh errors handling authentication failures
  * fix ssh server connections and support 'none' authentication
  * fix start new command menu
  * fix appindicator failures when we fail to locate the default
    icon
  * fix command line tools usage under cygwin and terminal
    emulators
  * fix pointer position on multi-monitor shadow servers
  * fix system tray forwarding with python3 servers
  * fix window icons forwarding (MS Windows and MacOS mostly)
  * fix detection of splash window types
  * fix server startup errors when X11 root properties are
    invalid
  * fix shadow server startup failures on MacOS
  * fix system tray errors during shadow server startup on MacOS
  * fix printing errors with python3 builds and rencode packet
    encoder
  * fix parsing of printer options
  * fix dispatching of printer jobs to clients with python3
    servers
  * fix parsing of key symbol definitions with python3 servers
  * fix compatibility with older versions of GTK3
  * fix proxy video encoders initialization
  * fix 'missing encodings' server error with python3
  * fix spurious clipboard warning when clipboard is disabled
  * disable modal windows by default (was enabled by default
    since v2.3)
  * workaround buggy system trays
  * try harder to prevent hash collisions in scroll encoding
  * skip risky opengl probing when the initial check failed
  * prevent file conflicts with older packages
  * don't use appindicator with Fedora Gnome
  * minor packaging fixes (dates)
  * remove spurious ssh dnssec check logging
  * bump version in cups backend
* Tue Mar 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.5
  * Python 3 port mostly complete
  * pixel compression and bandwidth management:
    + better recovery from network congestion
    + distinguish refresh from normal updates
    + better tuning for mmap connections
    + heuristics improvements
    + use video encoders more aggressively
    + prevent too many delayed frames with x264
    + better video region detection with opengl content
  * better automatic tuning for client applications
    + based on application categories
    + application supplied hints
    + application window encoding hints
    + using environment variables and disabling video
  * HTML5 client improvements
  * Client improvements:
    + make it easier to start new commands, provide start menu
    + probe OpenGL in a subprocess to detect and workaround
    driver crashes
    + use appindicator if available
  * Server improvements:
    + start command on last client exit
    + honour minimum window size
    + Python 3
    + upgrade-desktop subcommand
  * Network layer:
    + less copying
    + use our own websocket layer
    + make mmap group configurable
    + TCP CORK support on Linux
  * SSH transport:
    + support .ssh/config with paramiko backend
    + connecting via ssh proxy hosts
  * SSHFP with paramiko:
    + clipboard: restrict clipboard data transfers size
  * code cleanups, etc
- Removed python2-opengl requirement (package not available
  and unnecessary since this release)
- Refreshed xpra-paths.patch
* Fri Mar  1 2019 Luigi Baldoni <aloisio@gmx.com>
- Enabled OpenGL (fixes boo#1127415)
- Added brotli as build requirement
- Refreshed xpra-paths.patch
* Thu Jan 31 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.4.3
  * fix minor glib timer handle leak and unnecessary timer
    scheduling
  * fix keyboard backwards compatibility with older 1.0 servers
  * fix error in keyboard debug logging
  * fix h264 decoding in HTML5 client
  * fix session info and bug report windows not getting
    dismissed in HTML5 client
  * fix precise wheel motion events with HTML5 client
  * fix clipboard with MacOS GTK2 clients
  * fix swap-keys menu entry wrongly disabled
  * fix potential memory leaks and errors in codecs due to cast
    error
  * fix crashy codecs on MS Windows: disable x264, 32-bit vpx
    with large sizes
  * fix validation errors with some quality and speed control
    commands
  * fix buggy parsing of clipboard-contents packets
  * fix jpeg encoder and decoder library version requirements
    (ie: for CentOS 7.x)
  * fix starting sessions via ssh on Ubuntu (workaround buggy
    systemd-run)
  * fix MS Windows clients handling system tray icons without an
    alpha channel
  * fix error in video exception message formating
  * fix errors handling pointer events with extra relative
    pointer data
  * fix potential string substitution errors with python2
  * fix connection to hosts that resolve to ipv6 only addresses
  * fix dbus mixin attributes initialized twice (wrong values)
  * fix race condition error with network congestion events
  * fix compatibility with newer ArchLinux Xorg path
  * fix exec-auth module timeout not being honoured
  * fix exec-auth wrongly returning success on MacOS
  * workaround SSH errors with Windows Services for Linux
  * reduce impact of fullscreen and maxmimized attributes on
    window refresh rate
  * never lock the batch delay when mmap is enabled
* Wed Dec  5 2018 aloisio@gmx.com
- Update to version 2.4.2
  * fix server crash with application setting invalid X11 atoms
  * fix missing windows with some mono applications (ignore
    invalid X11 atoms)
  * fix small X11 memory leak
  * fix encoding of empty areas (hard to trigger)
  * fix client hangs due to signal-watcher (now disabled with
    python2)
  * fix virtual printer cleanup errors
  * fix leaking xvfb processes when displayfd times out
  * fix window size hints not being sanitized correctly
  * fix cpu waste and automatic quality calculations
  * fix statistics used by shadow servers
  * fix error capturing screenshots on MS Windows
  * fix logging error in modifier state change failure code path
  * fix nvenc errors with odd image heights
  * fix over aggressive screen update rectangle merging
  * fix race condition causing the connection cleanup code to
    run twice
  * fix ssh dialog button actions
  * ensure Qt applications use the X11 backend so we can
    intercept them
  * skip unnecessary video tests when mmap is enabled
  * handle property change handlers errors more gracefully
  * avoid recycling video contexts unnecessarily
  * don't flush video encoders when doing a regular content
    refresh
* Sun Nov  4 2018 Jan Engelhardt <jengelh@inai.de>
- Make xpra-html5 subpackage noarch
- Speed up find -exec
* Sun Nov  4 2018 Luigi Baldoni <aloisio@gmx.com>
- Dropped xpra-rpmlintrc
* Thu Nov  1 2018 aloisio@gmx.com
- Update to version 2.4.1
  * fix popup window focus for some Java applications
  * fix popup window focus issue (ie: xterm menu)
  * fix system tray errors when mmap is disabled
  * fix missing codecs (numpy was blocked from loading)
  * fix nvenc compatibility with more python / cython / OS
    versions
  * fix backwards compatibility in keyboard mapping
  * fix session info errors when connecting to older servers
  * fix man page typo
  * fix default value 'auto' for ssh option, better compatibility
  * fix dead code triggering some debug warnings
  * fix rare race condition when closing a connection
  * fix 'flush' client encoding options parsing
  * fix overzealous clipboard sanitization code
  * fix missing notification messages
  * fix ssh client authentication: try all keys found
  * fix version update check
  * fix usability issues with GTK3, especially on MS Windows
  * fix cython compilation warnings
  * avoid ethtool warning spam
  * use correct headers for building python3 cairo workaround
    module
* Tue Oct 30 2018 Luigi Baldoni <aloisio@gmx.com>
- Added python2-paramiko as recommended runtime dependency
- Spec cleanup
* Fri Oct 26 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.4
  * SSH client integration (paramiko)
  * builtin server support for TCP socket upgrades to SSH
    (paramiko)
  * automatic TCP port allocation
  * expose desktop-sessions as VNC via mdns
  * add zeroconf backend
  * register more URL schemes
  * window content type heuristics configuration
  * use content type it to better tune automatic encoding
    selection
  * automatic video scaling
  * bandwidth-limit management in video encoders
  * HTML5 client mpeg1 and h264 decoding
  * HTML5 client support for forwarding of URL open requests
  * HTML5 client Internet Explorer 11 compatibility
  * HTML5 client toolbar improvements
  * HTML5 fullscreen mode support
  * limit video dimensions to cap CPU and bandwidth usage
  * keyboard layout handling fixes
  * better memory management and resource usage
  * new default GUI welcome screen
  * desktop file for starting shadow servers more easily
  * clipboard synchronization with multiple clients
  * use notifications bubbles for more important events
  * workarounds for running under Wayland with GTK3
  * modal windows enabled by default
  * support xdg base directory specification and socket file time
  * improved python3 support (still client only)
  * multi-window shadow servers on MacOS and MS Windows
  * buildbot upgrade
  * more reliable unit tests
  * fixes and workarounds for Java client applications
  * locally authenticated users can shutdown proxy servers
  * restrict potential privileged information leakage
  * enhanced per-client window filtering
  * remove extra pixel copy in opengl enabled client
  * clip pointer events to the actual window content size
  * new platforms: Ubuntu Cosmic, Fedora 29
- Refreshed xpra-paths.patch
- Spec cleanup
* Mon Oct  8 2018 aloisio@gmx.com
- Update to version 2.3.4
  * fix server does not shutdown cleanly (Xvfb not killed)
  * fix signals not emitted (ie: delay-tray command line option)
  * fix client desktop-scaling corner cases
  * fix handling of mixed clicks on system tray and the menu
    entries
  * fix MS Windows shadow server's cursor capture
  * fix URL parsing from launcher (ie: MacOS URL association)
  * fix MacOS crash with GTK3 builds and file chooser
  * fix non-opengl windows missing spinner with GTK3
  * fix RPM license information
  * fix mDNS zeroconf library version on MS Windows with Python 2
  * fix connection errors from making the client launcher exit
  * fix python3 errors in dbus server code
  * fix spurious error messages caused by video pipeline changes
  * fix proxy-video-encoders=all substitution
  * fix unicode string errors with RFB protocol and Python 3
  * fix missing idle and clipboard server information
  * fix .xpra file association with DEB packaging
  * fix pointer polling error with RFB connections (pointer
    going AWOL)
  * fix handling of closed RFB connections
  * fix unmanaged X11 call from shadow servers (potential
    crashes)
  * fix fallback pynotify notification handler
  * fix Python 3 shadow servers with RFB
  * fix Python 3 string errors writing run-xpra scripts
  * fix deadlocks with RFB connections
  * fix missing key mapping errors with RFB clients
  * fix session name not honoured or exposed via mdns for shadow
    servers
  * fix X11 display detection (socket may be owned by root with
    some display managers)
  * fix compatibility with csh and tcsh
  * fix spurious modifier key events from the HTML5 client
  * fix tray icon corruption on MS Windows
  * fix Motif WM hints parsing
  * fix DEB packaging dependencies
  * fix NVENC encoder wrongly exposing encodings which are not
    available
  * fix error running unit tests on MS Windows
  * fix potential file descriptor leak
  * fix valid XAuthority path potentially not found because
    unexpanded
  * fix proxy servers not honouring passwords in connection
    strings
  * fix sqlite authentication backend issue with identical
    usernames
  * support CUDA 10 and optimizations for Volta GPUs
  * Fedora 29 compatibility
  * fix race condition in unit tests which was causing random
    failures
  * add dependency required for running the unit tests with
    rpmbuild
  * prevent repeated clipboard warnings
  * let the server chooose the best initial quality to use
  * add file missing from clean build target
  * add missing entries in man page
  * add missing desktop file icons
  * shadow the current display if none is specified and we find
    more than one display
  * remove unneeded import, spurious debug logging
  * limit the amount of information exposed via the proxy
    server's dbus service
  * support base64 encoded SSL certificate data
  version 2.3.3
  * fix value shown in frame extents warning
  * fix HTML5 relative URLs for window control icons
  * fix HTML5 pointer events missing modifier keys
  * fix parsing errors when no display is specified
  * fix URL parsing with Python 3
  * fix tray setup errors on early client exit
  * fix putty plink PATH lookup issue
  * fix python3 compatibility for printer forwarding script
  * fix python3 alert box on MS Windows
  * fix python3 packaging on MS Windows
  * fix python3 client rendering of transparency with opengl
    disabled
  * fix file descriptor warnings on process exit with MS Windows
    builds
  * fix MS Windows monitor API overflow on 64-bit systems
  * fix compilation error with latest MSYS2 installations
  * fix desktop servers exit code
  * fix network congestion calculations when records expire
  * fix bandwidth warnings caused by slow client picture decoding
  * fix xpra info race condition error during cleanup
  * fix clipboard warnings: don't enable it unless the client
    requests it
  * fix spurious stacktraces caused by focus events on OR windows
  * fix painting of spinners with desktop-scaling and non-opengl
    backends
  * fix 'terminate server when command exits' from html5 client
  * fix SSL socket timeouts in proxy server
  * fix errors starting proxy instances if the user's home
    directory does not exist
  * fix ssh start remote command line compatibility mode
  * fix command line backwards compatibility
  * fix handling of tray geometry and keyboard detection failures
  * fix bandwidth-limit changes from the system tray menu
  * fix system version warnings on MacOS
  * force GTK3 Posix clients to use X11 backend (native Wayland
    crashes)
  * support cx_Freeze 5.x on MS Windows
  * don't require local user accounts with pam logins
  * drop invalid client connections without showing errors
    (desktop mode)
  * support building with Python 3.7 (some features made
    optional until ported over)
  * disable webcam forwarding with MS Windows client (broken
    upstream)
  * add missing RPM dependencies for running unit tests
  * prevent Python Pillow debug log spam
  * don't show spurious import errors during printing subsystem
    cleanup
  * show another possible reason for connection failures
  * make remote ssh command easier to parse
  * abort tests if build fails
  * use free colour profiles in all icon files
  * add missing man page entry for 'forward-xdg-open'
  * add missing files to manifest
  * man page typos
* Tue Jul 31 2018 jon@moozaad.co.uk
- added libsystemd build req to fix invalid /etc/default/xpra usage
* Wed Jul 18 2018 jon@moozaad.co.uk
- re-added xdummy args as auto detection wasn't enabling it
- reverted to python 2 for server support
- removed python 3 specific patch (cairo)
* Wed Jul 18 2018 jon@moozaad.co.uk
- switched to python3
- added webp support
- cleanup spec file of default build options
- now builds on Leap >= 42
- patched broken py3cairo detection
- Removed ffmpeg for <= Leap 15 (requires libav >= 58.18)
- Removed vpx for < Leap 15 (that leaves Leap 42.x with avcodec2 and webp)
* Wed Jul 18 2018 aloisio@gmx.com
- Update to version 2.3.2
  * fix notification actions support with shadow servers
  * fix paint errors with reformatted images using outdated
    stride value
  * fix control commands that call window refresh
  * fix broken pipe error when the browser cancels downloading
    the noicon placeholder
  * fix spurious refresh events
  * fix missing bug report data due to path errors
  * fix XAUTHORITY environment variable getting clobbered
  * fix html5 window refresh not throttled when the document is
    not visible
  * fix non-opengl painting of windows with a padding area
  * fix rgb paint of mmap data with the python2 cairo backend
  * fix invalid clipboard toggle requests not ignored
  * fix missing context handler for keymap setup (crash possible)
  * fix proxy server test to use a signal to stop the test
    instance
  * fix invalid exception value in X11 atom bindings
  * fix bandwidth limit client bypass and connection errors
  * fix building CUDA kernels with GCC 8.1
  * fix tray menu setup error when the clipboard is disabled
  * fix GTK3 buffer overflow with non-opengl backend
  * fix startup errors with pulseaudio if XDG_RUNTIME_DIR is
    missing
  * fix clipboard token send error when there are no targets
  * don't overwrite the dynamic system tray icon with the
    default one on startup
  * correctly disable desktop-scaling when mmap is enabled
  * skip repainting pointer overlay when the position is
    unchanged
  * prevent authenticated users from shutting down proxy servers
  * don't turn off notifications when we don't have a forwarder
    instance
  * don't try to log an exception that does not exist
  * allow the user to disable all video encoders and csc modules
  * send missing exception details to server with remote-logging
  * avoid RFB errors if screen capture fails
  * avoid further errors when shadow capture fails
  * recommend the dbus-x11 with the DEB package
  version 2.3.1:
  * fix CentOS / RHEL rpm dependencies for ldap authentication
  * fix spurious notifications warning
  * fix unsynced X11 context access to DPI (potential crash or
    warnings)
  * fix compilation warning in ffmpeg compatibility shim
  * fix filename extension check in launcher
  * fix h264 decoding in html5 client
  * fix menu stacking level in html5 client
  * fix focus issues with html5 client
  * fix socket error race condition during shutdown
  * fix scroll encoding errors on images with modified rowstride
  * fix desktop and shadow servers xinerama sizing issues
  * fix pixel encoding errors at low pixel depths
  * fix pixel-depth 8 wrongly rejected for start-desktop mode
  * fix colour encoding at pixel-depth 8
  * fix systemd warnings and packaging on Ubuntu 16.04
  * fix html5 client errors with audio debugging enabled
  * fix readonly mode bypass
  * fix client failure on servers without a valid desktop size
  * fix VNC connection handling of authentication
  * fix scary X11 desktop server warning with VNC clients
  * fix error in video debug logging
  * fix nvfbc errors during cleanup after initialization failures
  * fix client launcher not exiting on close
  * fix RFB clients causing sessions to be locked
  * fix rare deadlocks in exception handler
  * fix MacOS deprecation warnings
  * fix screen capture test script
  * fix CUDA DLL packaging
  * fix named-pipe errors with MS Windows Python3 and 64-bit
    builds
  * fix MinGW path detection issues
  * fix potential mmap leak with Python3 builds
  * fix screen update errors when XShm is disabled
  * silence GCC warnings when compiling NvFBC on MS Windows
  * increase default bandwidth congestion tolerance
  * remove duplicated DLLs from MS Windows Python3 builds
  * allow debugging via environment variables for all categories
  * don't prompt for the ssh password if we already have it
  * honour CFLAGS and LDFLAGS env vars
  * remove duplicated encoding from vpx encoder
  * add workaround for distributions shipping unpatched distutils
  * increase unit test failure timeout
  version 2.3:
  * stackable authentication modules
  * tcp wrappers authentication module
  * gss, kerberos, ldap and u2f authentication modules
  * request access to the session
  * pulseaudio server per session to prevent audio leaking
  * better network bandwidth utilization and congestion
    management
  * faster encoding and decoding: YUV for webp and jpeg, encoder
    hints, better vsync
  * notifications actions forwarding, custom icons, expose
    warnings
  * upload notification and management
  * shadow servers multi window mode
  * tighter client OS integratioin
  * client window positioning and multi-screen support
  * unique application icon used as tray icon
  * multi stop or attach
  * control start commands
  * forward signals sent to windows client side
  * forward requests to open URLs or files on the server side
  * html5 client improvements: top bar, debugging, etc
  * custom http headers, support content security policy
  * python3 port improvements
  * bug fixes: settings synchronization, macos keyboard mapping,
    etc
  * packaging: switch back to ffmpeg system libraries, support
    GTK3 on macos
  * structural improvements: refactoring, fewer synchronized X11
    calls, etc
  version 2.2:
  * support RFB clients (ie: VNC) with bind-rfb or rfb-upgrade
    options
  * UDP transport (experimental) with bind-udp and
    udp://host:port URLs
  * TCP sockets can be upgrade to Websockets and / or SSL, RFB
  * multiple bind options for all socket types supported: tcp,
    ssl, ws, wss, udp, rfb
  * bandwidth-limit option, support for very low bandwidth
    connections
  * detect network performance characteristics
  * "xpra sessions" browser tool for both mDNS and local sessions
  * support arbitrary resolutions with Xvfb (not with Xdummy yet)
  * new OpenGL backends, with support for GTK3 on most platforms
    and window transparency on MS Windows
  * optimized webp encoding, supported in HTML5 client
  * uinput virtual pointer device for supporting fine grained
    scrolling
  * connection strings now support the standard URI format
    protocol://host:port/
  * rencode is now used by default for the initial packet
  * skip sending audio packets when inactive
  * improved support for non-us keyboard layouts with non-X11
    clients
  * better modifier key support on Mac OS
  * clipboard support with GTK3
  * displayfd command line option
  * cosmetic system tray menu layout changes
  * dbus service for the system wide proxy server (stub)
  * move mmap file to $XDG_RUNTIME_DIR (where applicable)
  * password prompt dialog in client
  * fixed memory leaks
- Refreshed xpra-paths.patch
- Switched to ffmpeg4
* Fri Nov 10 2017 aloisio@gmx.com
- Update to version 2.1.3 (see NEWS)
- Refreshed xpra-paths.patch
* Wed Jul 26 2017 aloisio@gmx.com
- Update to version 2.1 (see NEWS)
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Wed Nov 12 2014 olaf@aepfle.de
- avoid republish after rebuild of unchanged sources
* Thu May 30 2013 pascal.bleser@opensuse.org
- update to 0.9.4
* Tue Apr 24 2012 pascal.bleser@opensuse.org
- initial version (0.2.0)
